@@ -1,6 +1,7 @@
 """Support for esphome sensors."""
 from __future__ import annotations
 
+from contextlib import suppress
 from datetime import datetime
 import math
 
@@ -14,7 +15,6 @@ from aioesphomeapi import (
 from aioesphomeapi.model import LastResetType
 
 from homeassistant.components.sensor import (
-    DEVICE_CLASSES,
     SensorDeviceClass,
     SensorEntity,
     SensorStateClass,
@@ -56,10 +56,6 @@ async def async_setup_entry(
     )
 
 
-# https://github.com/PyCQA/pylint/issues/3150 for all @esphome_state_property
-# pylint: disable=invalid-overridden-method
-
-
 _STATE_CLASSES: EsphomeEnumMapper[
     EsphomeSensorStateClass, SensorStateClass | None
 ] = EsphomeEnumMapper(
@@ -80,6 +76,7 @@ class EsphomeSensor(EsphomeEntity[SensorInfo, SensorState], SensorEntity):
         """Return if this sensor should force a state update."""
         return self._static_info.force_update
 
+    @property
     @esphome_state_property
     def native_value(self) -> datetime | str | None:
         """Return the state of the entity."""
@@ -99,11 +96,11 @@ class EsphomeSensor(EsphomeEntity[SensorInfo, SensorState], SensorEntity):
         return self._static_info.unit_of_measurement
 
     @property
-    def device_class(self) -> str | None:
+    def device_class(self) -> SensorDeviceClass | None:
         """Return the class of this device, from component DEVICE_CLASSES."""
-        if self._static_info.device_class not in DEVICE_CLASSES:
-            return None
-        return self._static_info.device_class
+        with suppress(ValueError):
+            return SensorDeviceClass(self._static_info.device_class)
+        return None
 
     @property
     def state_class(self) -> SensorStateClass | None:
@@ -116,7 +113,8 @@ class EsphomeSensor(EsphomeEntity[SensorInfo, SensorState], SensorEntity):
             state_class == EsphomeSensorStateClass.MEASUREMENT
             and reset_type == LastResetType.AUTO
         ):
-            # Legacy, last_reset_type auto was the equivalent to the TOTAL_INCREASING state class
+            # Legacy, last_reset_type auto was the equivalent to the
+            # TOTAL_INCREASING state class
             return SensorStateClass.TOTAL_INCREASING
         return _STATE_CLASSES.from_esphome(self._static_info.state_class)
 
@@ -124,6 +122,7 @@ class EsphomeSensor(EsphomeEntity[SensorInfo, SensorState], SensorEntity):
 class EsphomeTextSensor(EsphomeEntity[TextSensorInfo, TextSensorState], SensorEntity):
     """A text sensor implementation for ESPHome."""
 
+    @property
     @esphome_state_property
     def native_value(self) -> str | None:
         """Return the state of the entity."""
