@@ -12,6 +12,7 @@ from sqlalchemy.orm.session import Session
 from sqlalchemy.sql.expression import distinct
 
 from homeassistant.const import EVENT_STATE_CHANGED
+import homeassistant.util.dt as dt_util
 
 from .const import MAX_ROWS_TO_PURGE, SupportedDialect
 from .db_schema import Events, StateAttributes, States
@@ -233,7 +234,9 @@ def _select_state_attributes_ids_to_purge(
     """Return sets of state and attribute ids to purge."""
     state_ids = set()
     attributes_ids = set()
-    for state in session.execute(find_states_to_purge(purge_before)).all():
+    for state in session.execute(
+        find_states_to_purge(dt_util.utc_to_timestamp(purge_before))
+    ).all():
         state_ids.add(state.state_id)
         if state.attributes_id:
             attributes_ids.add(state.attributes_id)
@@ -251,7 +254,9 @@ def _select_event_data_ids_to_purge(
     """Return sets of event and data ids to purge."""
     event_ids = set()
     data_ids = set()
-    for event in session.execute(find_events_to_purge(purge_before)).all():
+    for event in session.execute(
+        find_events_to_purge(dt_util.utc_to_timestamp(purge_before))
+    ).all():
         event_ids.add(event.event_id)
         if event.data_id:
             data_ids.add(event.data_id)
@@ -264,21 +269,22 @@ def _select_event_data_ids_to_purge(
 def _select_unused_attributes_ids(
     session: Session, attributes_ids: set[int], using_sqlite: bool
 ) -> set[int]:
-    """Return a set of attributes ids that are not used by any states in the database."""
+    """Return a set of attributes ids that are not used by any states in the db."""
     if not attributes_ids:
         return set()
 
     if using_sqlite:
         #
-        # SQLite has a superior query optimizer for the distinct query below as it uses the
-        # covering index without having to examine the rows directly for both of the queries
-        # below.
+        # SQLite has a superior query optimizer for the distinct query below as it uses
+        # the covering index without having to examine the rows directly for both of the
+        # queries below.
         #
         # We use the distinct query for SQLite since the query in the other branch can
         # generate more than 500 unions which SQLite does not support.
         #
         # How MariaDB's query optimizer handles this query:
-        # > explain select distinct attributes_id from states where attributes_id in (136723);
+        # > explain select distinct attributes_id from states where attributes_id in
+        #   (136723);
         # ...Using index
         #
         seen_ids = {
@@ -289,15 +295,16 @@ def _select_unused_attributes_ids(
         }
     else:
         #
-        # This branch is for DBMS that cannot optimize the distinct query well and has to examine
-        # all the rows that match.
+        # This branch is for DBMS that cannot optimize the distinct query well and has
+        # to examine all the rows that match.
         #
-        # This branch uses a union of simple queries, as each query is optimized away as the answer
-        # to the query can be found in the index.
+        # This branch uses a union of simple queries, as each query is optimized away
+        # as the answer to the query can be found in the index.
         #
-        # The below query works for SQLite as long as there are no more than 500 attributes_id
-        # to be selected. We currently do not have MySQL or PostgreSQL servers running in the
-        # test suite; we test this path using SQLite when there are less than 500 attributes_id.
+        # The below query works for SQLite as long as there are no more than 500
+        # attributes_id to be selected. We currently do not have MySQL or PostgreSQL
+        # servers running in the test suite; we test this path using SQLite when there
+        # are less than 500 attributes_id.
         #
         # How MariaDB's query optimizer handles this query:
         # > explain select min(attributes_id) from states where attributes_id = 136723;
@@ -344,7 +351,7 @@ def _purge_unused_attributes_ids(
 def _select_unused_event_data_ids(
     session: Session, data_ids: set[int], using_sqlite: bool
 ) -> set[int]:
-    """Return a set of event data ids that are not used by any events in the database."""
+    """Return a set of event data ids that are not used by any events in the db."""
     if not data_ids:
         return set()
 
@@ -376,7 +383,6 @@ def _select_unused_event_data_ids(
 def _purge_unused_data_ids(
     instance: Recorder, session: Session, data_ids_batch: set[int], using_sqlite: bool
 ) -> None:
-
     if unused_data_ids_set := _select_unused_event_data_ids(
         session, data_ids_batch, using_sqlite
     ):
@@ -386,7 +392,10 @@ def _purge_unused_data_ids(
 def _select_statistics_runs_to_purge(
     session: Session, purge_before: datetime
 ) -> list[int]:
-    """Return a list of statistic runs to purge, but take care to keep the newest run."""
+    """Return a list of statistic runs to purge.
+
+    Takes care to keep the newest run.
+    """
     statistic_runs = session.execute(find_statistics_runs_to_purge(purge_before)).all()
     statistic_runs_list = [run.run_id for run in statistic_runs]
     # Exclude the newest statistics run
@@ -413,14 +422,16 @@ def _select_short_term_statistics_to_purge(
 def _select_legacy_event_state_and_attributes_and_data_ids_to_purge(
     session: Session, purge_before: datetime
 ) -> tuple[set[int], set[int], set[int], set[int]]:
-    """Return a list of event, state, and attribute ids to purge that are linked by the event_id.
+    """Return a list of event, state, and attribute ids to purge linked by the event_id.
 
     We do not link these anymore since state_change events
     do not exist in the events table anymore, however we
     still need to be able to purge them.
     """
     events = session.execute(
-        find_legacy_event_state_and_attributes_and_data_ids_to_purge(purge_before)
+        find_legacy_event_state_and_attributes_and_data_ids_to_purge(
+            dt_util.utc_to_timestamp(purge_before)
+        )
     ).all()
     _LOGGER.debug("Selected %s event ids to remove", len(events))
     event_ids = set()
@@ -669,7 +680,8 @@ def purge_entity_data(instance: Recorder, entity_filter: Callable[[str], bool])
         ]
         _LOGGER.debug("Purging entity data for %s", selected_entity_ids)
         if len(selected_entity_ids) > 0:
-            # Purge a max of MAX_ROWS_TO_PURGE, based on the oldest states or events record
+            # Purge a max of MAX_ROWS_TO_PURGE, based on the oldest states
+            # or events record.
             _purge_filtered_states(instance, session, selected_entity_ids, using_sqlite)
             _LOGGER.debug("Purging entity data hasn't fully completed yet")
             return False
